---
title: <span class="badge object-type-scalar"></span> IndianRupee
---
# <span class="badge object-type-scalar"></span> IndianRupee

Currency: Indian Rupee (₹)

## Definition

```python
# Currency: Indian Rupee (₹)
IndianRupee: typing.Literal["currencyINR"] = "currencyINR"
```
